@@ -1,5 +1,5 @@
 /* Tools for editing a PR.
-   Copyright (C) 1994, 1995, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 2001, 2002 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
 
 This file is part of GNU GNATS.
@@ -476,22 +476,25 @@ validateFieldValue (FieldIndex field, const char *text, ErrorDesc *err,
       break;
     case Integer:
       {
-	const char *tptr = text;
-	if (tptr[0] == '-' || tptr[0] == '+')
+	if (text != NULL)
 	  {
-	    tptr++;
-	  }
-	while (tptr[0] != '\0')
-	  {
-	    if (! isdigit ((int) tptr[0]))
+	    const char *tptr = text;
+	    if (tptr[0] == '-' || tptr[0] == '+')
 	      {
-		setError (err, CODE_INVALID_FIELD_CONTENTS,
-			  newBadFieldEntry (field, text, NULL),
-			  "Integer field %s had non-integer contents",
-			  fieldDefForIndex (field)->name);
-		return 0;
+		tptr++;
+	      }
+	    while (tptr[0] != '\0')
+	      {
+		if (! isdigit ((int) tptr[0]))
+		  {
+		    setError (err, CODE_INVALID_FIELD_CONTENTS,
+			      newBadFieldEntry (field, text, NULL),
+			      "Integer field %s had non-integer contents",
+			      fieldDefForIndex (field)->name);
+		    return 0;
+		  }
+		tptr++;
 	      }
-	    tptr++;
 	  }
       }
       break;
@@ -548,7 +551,7 @@ validateFieldValue (FieldIndex field, const char *text, ErrorDesc *err,
 	}
       for (rl = fieldDefForIndex (field)->regex; rl != NULL; rl = rl->next)
 	{
-	  if (regcmp (rl->name, rtextToCheck, NULL) == 0)
+	  if (gnats_regcmp (rl->name, rtextToCheck, NULL) == 0)
 	    {
 	      break;
 	    }
@@ -982,12 +985,12 @@ applyFieldEdit (PR *pr, FieldEdit *edit, ErrorDesc *err,
 
 	      vptr = value;
 
-	      while (*value != '\0' && isspace ((int) *value))
+	      while (*value != '\0' && isspace ((int)(unsigned char) *value))
 		{
 		  value++;
 		}
 
-	      while (vend >= value && isspace ((int) *vend))
+	      while (vend >= value && isspace ((int)(unsigned char) *vend))
 		{
 		  *(vend--) = '\0';
 		}
@@ -1101,7 +1104,8 @@ applyChangeAction (ChangeActions action, PR *pr, PR *oldPR, FieldIndex field,
 
   while (fields != NULL)
     {
-      if (get_field_value (pr, oldPR, fields->ent, NULL, NULL) == NULL)
+      const char *fldval = get_field_value (pr, oldPR, fields->ent, NULL, NULL);
+      if (value_is_empty (fldval))
 	{
 	  setError (err, CODE_INVALID_PR_CONTENTS,
 		    "Required field %s missing from PR %s.",
