@@ -1,6 +1,5 @@
 /* Define all procedures which are external to each other.
-   Copyright (C) 2001 Milan Zamazal
-   Copyright (C) 1993, 1995, 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1995, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
    Contributed by Tim Wicinski (wicinski@barn.com).
    Hacked by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org).
@@ -86,6 +85,10 @@ extern int errno;
 #else
 #include <sys/file.h>
 #endif
+ 
+#ifdef HAVE_LIBGEN_H
+#include <libgen.h>
+#endif
 
 #ifndef alloca
 /* Make alloca work the best possible way.  */
@@ -210,7 +213,7 @@ extern const int EXIT_OK;
 extern const int EXIT_PROGRAM_ERROR;
 
 /* Files that controls access to the database. */
-#define DB_ACCESS_FILE "gnatsd.access"
+#define DB_ACCESS_FILE "gnatsd.user_access"
 #define DB_HOST_ACCESS_FILE "gnatsd.host_access"
 
 /* Default values of field properties. */
@@ -354,7 +357,7 @@ extern const char *get_prid_from_path (const char*);
 extern const char *get_cat_prid_from_path (const char*);
 extern char *get_lock_path (const DatabaseInfo database, const char *prID);
 extern char *get_curr_date (void);
-extern int gnatsdbHasNetconn (void);
+extern int gnatsdbHasNetconn (const char *database_name);
 extern int isPrLocked (const DatabaseInfo database, const char *prNum);
 extern int fileExists (const char *filename);
 extern void setError (ErrorDesc *errorDesc, int errorCode, ...);
