@@ -406,10 +406,14 @@ get_curr_date (void)
 }
 
 int
-gnatsdbHasNetconn (void)
+gnatsdbHasNetconn (const char *database_name)
 {
   const char *var = getenv ("GNATSDB");
-  if (var != NULL && var[0] != '\0')
+  if (database_name != NULL && database_name[0] != '\0')
+    {
+      return databaseSpecIsNetConn (database_name);
+    }
+  else if (var != NULL && var[0] != '\0')
     {
       if (strchr (var, ':') != NULL)
 	{
