@@ -37,6 +37,7 @@ struct list_type_list {
   { "States",             ListStates,             ".sta", "state" },
   { "FieldNames",         ListFieldNames,         ".fns", NULL },
   { "InitialInputFields", ListInitialInputFields, ".lfn", NULL },
+  { "InitialRequiredFields", ListInitialRequiredFields, ".lrn", NULL },
   { "Databases",          ListDatabases,          ".dbl", NULL },
   { NULL,		  InvalidListType,	  NULL,   NULL }
 };
@@ -145,6 +146,16 @@ getGnatsFile (const DatabaseInfo database, ListTypes whichList,
 	  }
 	break;
       }
+    case ListInitialRequiredFields:
+      {
+	FieldList fields = getRequiredInputFields(database);
+	while (fields != NULL)
+	  {
+	    fprintf (fpout, "%s\n", complexFieldIndexToString (fields->ent));
+	    fields = fields->next;
+	  }
+	break;
+      }
     case ListDatabases:
       chain = getDatabaseList (&err);
       fieldCount = 3;
