@@ -93,7 +93,7 @@ log_msg (int severity, int num_arg, va_dcl va_alist)
 	{
 #ifdef HAVE_SYSLOG_H
 	case SYSLOG:
-	  syslog (severity, buf);
+	  syslog (severity, "%s", buf);
 	  break;
 #endif
 	case MAIL:
@@ -557,23 +557,51 @@ gnats_strftime (char *s, size_t size, const char *template,
     {
       char buf[16];
       strftime (buf, 16, "%z", brokentime);
-      have_strftime_with_z = isdigit ((int)(buf[1]));
+      /* jonm@alchemetrics.co.uk - added check for +/- at the start
+      ** of the string to support SCO OpenServer.  The undocumented
+      ** %z does not have a '+' on for positive offsets, so the 
+      ** return from get_curr_date() cannot be parsed by get_date().
+      */
+      have_strftime_with_z = ((int)buf[0] == '+' || (int)buf[0] == '-') &&
+	      isdigit ((int)(buf[1]));
     }
   
   if (have_strftime_with_z)
     return strftime (s, size, template, brokentime);
   else
     {
-      const int FORMAT_PADDING = 30;  /* 3 extra chars for each %z */
-      char *fixed_template = (char*)xmalloc (strlen(template)+FORMAT_PADDING);
+      int padding = 0;
       const char *in = template;
-      char *out = fixed_template;
+      char *fixed_template = 0;
+      char *out = 0;
       /* Because brokentime points to static data (allocated
        * by localtime()), it cannot be passed to a subroutine
        * and then later be relied on to point to the same data. */
       struct tm btime = *brokentime;
       int result;
      
+      /* Count number of %z so we know how much characters to add to the
+       * template.  We actually count the number of additional characters.
+       * As we are going to replace each "%z" by "+hhmm" (sign, hours,
+       * minutes), this is 3 extra chars for each %z. */
+      while (*in)
+	{
+	  if (*in == '%' && *(in+1) == 'z')
+	    {
+	      in += 2;
+	      padding += 3;  /* 3 extra chars for each %z */
+	    }
+	  else
+	    {
+	      in++;
+	    }
+	}
+
+      /* Now allocate enough space. */
+      fixed_template = (char*)xmalloc (strlen(template)+padding+1);
+      in = template;  /* Inspect it again, this time replacing all %z. */
+      out = fixed_template;
+     
       while (*in != '\0')
 	{
 	  char c = *in++;
