@@ -1,5 +1,5 @@
 /* Give stats on PRs regarding their lifetime from open to closed state.
-   Copyright (C) 1994, 1995 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 2002 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
 
 This file is part of GNU GNATS.
@@ -38,8 +38,7 @@ typedef struct _times
 
 struct option long_options[] =
 {
-/*  {"business-time", 0, NULL, 'b'},*/
-/*  {"help", 0, NULL, 'h'},*/
+  {"help", 0, NULL, 'h'},
   {"database", 1, NULL, 'd'},
   {"version", 0, NULL, 'V'},
   {NULL, 0, NULL, 0}
